# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
#
#
# Authors:  Hammad Haleem <hammadhaleem@gmail.com>

""" Tests for Fedora College Message """

import unittest
import datetime

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestMediaUploadBase():

    """ These messages are for people when
    they upload stuff to fedora College portal`_.
    """

    expected_title = "fedoracollege.media.upload"
    expected_subtitle = 'pingou uploaded a new file of type "image"'
    expected_link = "http://testlink"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "fedoracollege.media.upload",
        "link": "https://FedoraCollege.org/testlink",
        "msg":
        {
                    "title": "image",
                    "link": "https://testlink",
                    "content_url": "http://demo.engineerinme.com/static/uploads/\
                    hammadhaleem/1404190396.4603c7aec5\
                    a7f21a64a4489fc68d762168.png",
                    "file_type": "image",
                    "filename": "1404190396.4603c7aec5a7f\
                    21a64a4489fc68d762168.png",
                    "id": "1",
                    "name": "File upload",
                    "sys_path ": "/home/engineer/fedora-college/fedora_college/static/\
                    uploads/hammadhaleem/34343423.png",
                    "tags": "fedora-college  image-upload website ",
                    "thumb": "static/uploads/hammadhaleem/1404190396.4603c7aec5a7f21a64a4489f\
                    c68d762168.png_thumb.jpg",
                    "timestamp": "2014-07-01 04:53:16.599954",
                    "username": "pingou"
        }
    }


class TestContentEdit(Base):

    """ These messages are published when
    someone edit content in the fedora College.
    """
    expected_title = "fedoracollege.content.edit"
    expected_subtitle = 'pingou Edited content titled "test"'
    expected_link = "http://testlink"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "fedoracollege.content.edit",
        "link": "https://FedoraCollege.org/testlink",
        "msg":
        {
                    "title": "test",
                    "link": "https://testlink",
                    "active": True,
                    "date_added": "Tue, 01 Jul 2014 19:07:00 GMT",
                    "description": "The Content available on this\
                    website is contributed from people in fedora\
                    community. Mostly all\
                    the content has CC licence.</p>",
                    "id": 2,
                    "media_added_ids": "",
                    "slug": "about-the-content",
                    "tags": "fedora-college, blog",
                    "title": "About the content",
                    "type": "blog",
                    "username": "pingou"
        }
    }


class TestContentAdded(Base):

    """ These messages are published when
    someone edit content in the fedora College.
    """

    expected_title = "fedoracollege.content.edit"
    expected_subtitle = 'pingou Created new content titled "test"'
    expected_link = "http://testlink"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "fedoracollege.content.added",
        "link": "https://FedoraCollege.org/testlink",
        "msg": {
            "title": "test",
            "link": "https://testlink",
            "active": True,
                    "date_added": "Tue, 01 Jul 2014 19:07:00 GMT",
                    "description": "The Content available on this\
                    website is contributed from people in fedora\
                    community. Mostly all\
                    the content has CC licence.</p>",
                    "id": 2,
                    "media_added_ids": "",
                    "slug": "about-the-content",
                    "tags": "fedora-college, blog",
                    "title": "About the content",
                    "type": "blog",
                    "username": "pingou"
        }
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



import fedmsg.tests.test_meta
import arrow

import os


class TestMeetbotConglomerateByURL(
        fedmsg.tests.test_meta.ConglomerateBase):
    expected = [{
        'subtitle': u'alexove, echevemaster, and 4 others participated in Fedora Latam Ambassadors Meeting in #fedora-meeting-2',
        'subjective': u'alexove, echevemaster, and 4 others participated in Fedora Latam Ambassadors Meeting in #fedora-meeting-2',
        'secondary_icon': 'https://seccdn.libravatar.org/avatar/928a57107752819b7dd75177b094733dd4ea881dc0c68f4430fcf3ddc7610aa6?s=64&d=retro',
        'icon': 'https://apps.fedoraproject.org/img/icons/meetbot.png',
        'link': 'https://meetbot.fedoraproject.org/fedora-meeting-2/2016-03-05/fedora_latam_ambassadors_meeting.2016-03-05-23.13',

        'packages': set([]),
        'categories': set(['meetbot']),

        'timestamp': 1457220101.0,
        'start_time': 1457219627.0,
        'end_time': 1457221175.0,
        'human_time': arrow.get(1457220101.0).humanize(),

        'topics': set([
            'org.fedoraproject.prod.meetbot.meeting.complete',
            'org.fedoraproject.prod.meetbot.meeting.item.link',
            'org.fedoraproject.prod.meetbot.meeting.start',
            'org.fedoraproject.prod.meetbot.meeting.topic.update',
        ]),
        'usernames': set([
            'alexove',
            'echevemaster',
            'lorddemon',
            'srkraken',
            'yn1v',
        ])
    }, {
        'subjective': u'decause, jflory7, and 2 others participated in BrickHack 2016 - FOSS Contributions and Licensing in #fedora-meeting-4',
        'subtitle': u'decause, jflory7, and 2 others participated in BrickHack 2016 - FOSS Contributions and Licensing in #fedora-meeting-4',

        'categories': set(['meetbot']),
        'icon': 'https://apps.fedoraproject.org/img/icons/meetbot.png',
        'link': 'https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00',
        'packages': set([]),
        'secondary_icon': 'https://seccdn.libravatar.org/avatar/70d3fd3ea028073bfab8d315504133b203992d4d8eb8daf1ca4397c222377ee6?s=64&d=retro',
        'timestamp': 1457218880.3333333,
        'start_time': 1457218567.0,
        'end_time': 1457219582.0,
        'human_time': arrow.get(1457218880.3333333).humanize(),
        'topics': set([
            'org.fedoraproject.prod.meetbot.meeting.complete',
            'org.fedoraproject.prod.meetbot.meeting.item.info',
            'org.fedoraproject.prod.meetbot.meeting.item.link',
        ]),
        'usernames': set(['decause', 'jflory7', 'mikedep333'])
    }]


    originals = [
        {
            "i": 651,
            "msg": {
                "attendees": {
                    "alexove": 11,
                    "echevemaster": 57,
                    "lorddemon": 8,
                    "srkraken": 3,
                    "yn1v": 24,
                    "zodbot": 9
                },
                "chairs": {
                    "echevemaster": True
                },
                "channel": "#fedora-meeting-2",
                "details": {
                    "line": "",
                    "linenum": 112,
                    "nick": "echevemaster",
                    "time_": 1457221175.0
                },
                "meeting_topic": "Fedora Latam Ambassadors Meeting",
                "owner": "echevemaster",
                "topic": "roll call",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-2/2016-03-05/fedora_latam_ambassadors_meeting.2016-03-05-23.13"
            },
            "msg_id": "2016-c054b4c5-9aa5-4392-a688-77de1ed7c22b",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457221175.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.complete"
        },
        {
            "i": 650,
            "msg": {
                "attendees": {
                    "alexove": 2,
                    "echevemaster": 10,
                    "lorddemon": 3,
                    "srkraken": 2,
                    "yn1v": 9,
                    "zodbot": 8
                },
                "chairs": {
                    "echevemaster": True
                },
                "channel": "#fedora-meeting-2",
                "details": {
                    "line": "https://fedoraproject.org/wiki/Foro_UCR_2016",
                    "linenum": 34,
                    "nick": "yn1v",
                    "time_": 1457219965.0
                },
                "meeting_topic": "Fedora Latam Ambassadors Meeting",
                "owner": "echevemaster",
                "topic": "roll call",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-2/2016-03-05/fedora_latam_ambassadors_meeting.2016-03-05-23.13"
            },
            "msg_id": "2016-657de7d5-c221-465d-9a7a-21cc6caf1f47",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219965.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.link"
        },
        {
            "i": 649,
            "msg": {
                "attendees": {
                    "echevemaster": 2,
                    "zodbot": 3
                },
                "chairs": {
                    "echevemaster": True
                },
                "channel": "#fedora-meeting-2",
                "details": {
                    "line": "roll call",
                    "linenum": 5,
                    "nick": "echevemaster",
                    "time_": 1457219637.0
                },
                "meeting_topic": "Fedora Latam Ambassadors Meeting",
                "owner": "echevemaster",
                "topic": "roll call",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-2/2016-03-05/fedora_latam_ambassadors_meeting.2016-03-05-23.13"
            },
            "msg_id": "2016-cf7710f9-1c19-4816-9d6f-1f75438325ad",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219637.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.topic.update"
        },
        {
            "i": 647,
            "msg": {
                "attendees": {
                    "echevemaster": 1
                },
                "chairs": {
                    "echevemaster": True
                },
                "channel": "#fedora-meeting-2",
                "details": {
                    "line": "Fedora Latam Ambassadors Meeting",
                    "linenum": 1,
                    "nick": "echevemaster",
                    "time_": 1457219627.0
                },
                "meeting_topic": "Fedora Latam Ambassadors Meeting",
                "owner": "echevemaster",
                "topic": "",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-2/2016-03-05/fedora_latam_ambassadors_meeting.2016-03-05-23.13"
            },
            "msg_id": "2016-90fa8f7e-af6e-4876-b5ea-a65dd9b440a6",
            "source_version": "0.6.5",
            "timestamp": 1457219627.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.start"
        },
        {
            "i": 646,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 69,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "",
                    "linenum": 115,
                    "nick": "jflory7",
                    "time_": 1457219582.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-06dbd60e-259e-4125-a1fd-63add8a5c205",
            "source_name": "datanommer",
            "timestamp": 1457219582.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.complete"
        },
        {
            "i": 644,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 68,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "https://lists.fedoraproject.org/archives/list/commops@lists.fedoraproject.org/",
                    "linenum": 114,
                    "nick": "jflory7",
                    "time_": 1457219168.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-f4f3af68-986f-48b1-a31e-d1463de2bfe6",
            "source_version": "0.6.5",
            "timestamp": 1457219168.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.link"
        },
        {
            "i": 643,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 67,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Check out the #fedora-commops IRC channel on Freenode!",
                    "linenum": 113,
                    "nick": "jflory7",
                    "time_": 1457219127.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-7c134589-30e8-4c70-8ebf-d98dc5403576",
            "source_name": "datanommer",
            "timestamp": 1457219127.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 642,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 66,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Remy works on the Community Operations (CommOps) team and is *super* glad to help anyone get started",
                    "linenum": 112,
                    "nick": "jflory7",
                    "time_": 1457219105.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-ccce4b2a-937b-4c30-bfd2-818777a39201",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219105.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 641,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 65,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Choose your own adventure! The above site is a sorting hat that can help you choose a place to contribute",
                    "linenum": 111,
                    "nick": "jflory7",
                    "time_": 1457219084.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-c7976d40-e70c-46cf-98e1-6c0f1a8b8aff",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219084.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 640,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 64,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "http://whatcanidoforfedora.org/",
                    "linenum": 110,
                    "nick": "jflory7",
                    "time_": 1457219045.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-2a374faf-0ec9-4d3d-95bc-64fc2ec4828a",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219045.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.link"
        },
        {
            "i": 639,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 63,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Q: \"Fedora looks cool but how can I contribute?\"",
                    "linenum": 109,
                    "nick": "jflory7",
                    "time_": 1457219041.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-781a5269-d215-448f-ac52-cd0714bcfb4d",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457219041.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 638,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 62,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Email licensing@fsf.org for 1x1 advice or help",
                    "linenum": 108,
                    "nick": "jflory7",
                    "time_": 1457218955.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-f09d3931-5e72-47ee-aa1e-186aaece1061",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218955.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 637,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 61,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "https://sfconservancy.org/",
                    "linenum": 107,
                    "nick": "jflory7",
                    "time_": 1457218925.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-cbe4fd33-b075-4e85-9fef-54015cb237d8",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218925.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.link"
        },
        {
            "i": 636,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 60,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Questions about FOSS legal?? Not sure who to ask??",
                    "linenum": 106,
                    "nick": "jflory7",
                    "time_": 1457218905.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-f3a8d1fa-1421-42b4-85b2-66ff7d48d167",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218905.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 635,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 59,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "There are many layers to this in a legal aspect and technological literacy to the nth degree is important",
                    "linenum": 105,
                    "nick": "jflory7",
                    "time_": 1457218854.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-0280bf12-c02e-4496-a0b0-a4ee82903670",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218854.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 634,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 58,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "NOTE REMY IS NOT A LAWYER AND THIS DOES NOT CONSTITUTE LEGAL ADVICE",
                    "linenum": 104,
                    "nick": "jflory7",
                    "time_": 1457218779.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-f336da43-7c1e-4b8d-a03d-04163e2e8c49",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218779.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 633,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 57,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Changing a license is a very permanent thing -- you need 100% agreement by all contributors ever to change the license",
                    "linenum": 103,
                    "nick": "jflory7",
                    "time_": 1457218762.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-237af8bc-c7bd-4f87-9b35-93ad425e18fd",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218762.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 632,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 56,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "In Fedora, you can use any list of approved licenses, if you don't specify, it defaults to MIT (permissive) license",
                    "linenum": 102,
                    "nick": "jflory7",
                    "time_": 1457218738.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-66cf6ebc-5604-4a7b-892a-1af856bc86d4",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218738.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 631,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 55,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Often you sign a Contributor Licensing Agreement that defines the terms",
                    "linenum": 101,
                    "nick": "jflory7",
                    "time_": 1457218714.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-6e8a812b-fdbe-4674-b25f-9d734509e485",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218714.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 630,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 54,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Imagine a timeline -- there's different milestones that can factor into when or how the code licensing can be changed",
                    "linenum": 100,
                    "nick": "jflory7",
                    "time_": 1457218699.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-e26c466e-b654-4703-98ec-29fad51d416a",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218699.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 629,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 53,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Licensing: Difficult to go from copyleft to permissive, easier the other way around",
                    "linenum": 99,
                    "nick": "jflory7",
                    "time_": 1457218664.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-27a0e6fc-4d99-4fdc-8194-06b451f9d9e9",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218664.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 628,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 52,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "To get contributors: Have clear on-boarding paths, have good docs, have good communication (not \"RTFM or get out\")",
                    "linenum": 98,
                    "nick": "jflory7",
                    "time_": 1457218620.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-5a62f199-475f-4aaf-a60b-0273507c32f4",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218620.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 627,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 51,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "Many different reasons people contribute to open source",
                    "linenum": 97,
                    "nick": "jflory7",
                    "time_": 1457218581.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-0546d52d-cf1b-4292-883e-5c4b4dc09dcf",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218581.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 626,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 50,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "After that, it comes down to culture",
                    "linenum": 96,
                    "nick": "jflory7",
                    "time_": 1457218572.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-45d354ce-a272-4a56-a9cf-160dc690e474",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218572.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        },
        {
            "i": 625,
            "msg": {
                "attendees": {
                    "decause": 3,
                    "jflory7": 49,
                    "mikedep333": 35,
                    "zodbot": 8
                },
                "chairs": {
                    "decause": True,
                    "jflory7": True,
                    "mikedep333": True
                },
                "channel": "#fedora-meeting-4",
                "details": {
                    "line": "In FOSS, if you scratch an \"itch\" for something that someone has, there's a good chance someone will find you",
                    "linenum": 95,
                    "nick": "jflory7",
                    "time_": 1457218567.0
                },
                "meeting_topic": "BrickHack 2016 - FOSS Contributions and Licensing",
                "owner": "jflory7",
                "topic": "Questions & Answers",
                "url": "https://meetbot.fedoraproject.org/fedora-meeting-4/2016-03-05/famna.2016-03-05-22.00"
            },
            "msg_id": "2016-5e6623a2-c62b-420c-905c-04ccbb5cef48",
            "source_name": "datanommer",
            "source_version": "0.6.5",
            "timestamp": 1457218567.0,
            "topic": "org.fedoraproject.prod.meetbot.meeting.item.info"
        }
    ]


if 'FEDMSG_META_NO_NETWORK' in os.environ:
    TestMeetbotConglomerateByURL = None



# This file is part of fedmsg.
# Copyright (C) 2015 Sayan Chowdhury.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Sayan Chowdhury <sayanchowdhury@fedoraproject.org>

from fedmsg_meta_fedora_infrastructure import BaseProcessor


class AutoCloudProcessor(BaseProcessor):
    __name__ = "autocloud"
    __description__ = "Automated Fedora Cloud Image Testing service"
    __link__ = "https://github.com/kushaldas/autocloud"
    __docs__ = "https://github.com/kushaldas/autocloud"
    __icon__ = "https://apps.fedoraproject.org/img/icons/fedimg.png"
    __obj__ = "Cloud Image Test"

    def subtitle(self, msg, **config):
        image_name = msg['msg']['image_name']
        status = msg['msg']['status']
        release = msg['msg'].get('release')
        if 'autocloud.image' in msg['topic']:
            if status == "queued":
                tmpl = self._("{image_name} is {status} for testing")
            if status == "running":
                tmpl = self._("The tests for the {image_name} have "
                              "started {status}")
            if status == "aborted":
                tmpl = self._("The tests for the {image_name} have "
                              "been {status}")
            if status == "failed":
                tmpl = self._("The tests for the {image_name} {status}")
            if status == "success":
                tmpl = self._("The tests for {image_name} were a {status}")

            if release:
                image_name = "%s (%s)" % (image_name, release)

            return tmpl.format(image_name=image_name, status=status)

    def secondary_icon(self, msg, **config):
        return self.__icon__

    def link(self, msg, **config):
        job_id = msg['msg'].get('job_id')
        if job_id:
            template = 'https://apps.fedoraproject.org/autocloud/jobs/%s/output'
            return template % job_id
        else:
            return msg['msg']['image_url']

    def objects(self, msg, **config):
        status = msg['msg']['status']
        return set(['autocloud/image/' + status])



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#

config = dict(
    endpoints={
        # This is the output side of the relay to which all other
        # services can listen.
        "relay_outbound": [
            "tcp://127.0.0.1:4001",
        ],
    },

    # This is the address of an active->passive relay.  It is used for the
    # fedmsg-logger command which requires another service with a stable
    # listening address for it to send messages to.
    # It is also used by the git-hook, for the same reason.
    # It is also used by the mediawiki php plugin which, due to the oddities of
    # php, can't maintain a single passive-bind endpoint of it's own.
    relay_inbound=[
        "tcp://127.0.0.1:2003",
    ],
)



import fedmsg.meta.base
from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url


class ByUserTag(fedmsg.meta.base.BaseConglomerator):
    def can_handle(self, msg, **config):
        return any([
            'bodhi.buildroot_override.tag' in msg['topic'],
        ])

    def matches(self, a, b, **config):
        """ The message must match by username """
        submitter_a = a['msg']['override']['submitter']['name']
        submitter_b = b['msg']['override']['submitter']['name']
        if submitter_a != submitter_b:
            return False
        return True

    def merge(self, constituents, subject, **config):
        N = len(constituents)
        msg = constituents[0]['msg']
        agent = msg['override']['submitter']['name']
        branches = self.list_to_series([
            constituent['msg']['override']['nvr'].split('.')[-1]
            for constituent in constituents])

        tmpl = self.produce_template(constituents, subject, **config)
        packages = self.list_to_series(list(tmpl['packages']))
        subtitle = '{agent} submitted {N} overrides for {packages} ' + \
            'on {branches}'
        tmpl['subtitle'] = subtitle.format(
            agent=agent, packages=packages, N=N, branches=branches)
        tmpl['subjective'] = tmpl['subtitle']
        tmpl['secondary_icon'] = avatar_url(agent)
        base = 'https://bodhi.fedoraproject.org/overrides/?user=%s'
        tmpl['link'] = base % agent
        return tmpl


class ByUserUnTag(fedmsg.meta.base.BaseConglomerator):
    def can_handle(self, msg, **config):
        return any([
            'bodhi.buildroot_override.untag' in msg['topic'],
        ])

    def matches(self, a, b, **config):
        """ The message must match by username """
        submitter_a = a['msg']['override']['submitter']['name']
        submitter_b = b['msg']['override']['submitter']['name']
        if submitter_a != submitter_b:
            return False
        return True

    def merge(self, constituents, subject, **config):
        N = len(constituents)
        msg = constituents[0]['msg']
        agent = msg['override']['submitter']['name']
        branches = self.list_to_series([
            constituent['msg']['override']['nvr'].split('.')[-1]
            for constituent in constituents])

        tmpl = self.produce_template(constituents, subject, **config)
        packages = self.list_to_series(list(tmpl['packages']))
        subtitle = '{agent} expired {N} overrides for {packages} ' + \
            'on {branches}'
        tmpl['subtitle'] = subtitle.format(
            agent=agent, packages=packages, N=N, branches=branches)
        tmpl['subjective'] = tmpl['subtitle']
        tmpl['secondary_icon'] = avatar_url(agent)
        base = 'https://bodhi.fedoraproject.org/overrides/?user=%s'
        tmpl['link'] = base % agent
        return tmpl



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#           Ralph Bean <rbean@redhat.com>

from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
from fedmsg_meta_fedora_infrastructure import BaseProcessor


class ElectionsProcessor(BaseProcessor):
    __name__ = "fedora_elections"
    __description__ = "the fedora voting system"
    __link__ = "https://apps.fedoraproject.org/voting/"
    __docs__ = "https://github.com/fedora-infra/elections"
    __obj__ = "Fedora Elections"

    def link(self, msg, **config):
        msg = msg['msg']
        if 'election' in msg:
            msg = msg['election']
        name = msg['alias']
        return "https://admin.fedoraproject.org/voting/about/%s" % (name)

    def subtitle(self, msg, **config):
        if 'election' in msg['msg']:
            name = msg['msg']['election']['alias']  # Old style
        else:
            name = msg['msg']['alias']  # New style

        if 'agent' in msg['msg']:
            agent = msg['msg']['agent']  # Old style
        else:
            agent = msg['msg']['fas_user']  # New style

        kwargs = dict(name=name, agent=agent)

        if 'election.new' in msg['topic']:
            tmpl = self._(
                '{agent} created election "{name}"')
        elif 'election.edit' in msg['topic']:
            tmpl = self._(
                '{agent} edited election "{name}"')
        elif 'candidate.new' in msg['topic']:
            tmpl = self._(
                '{agent} added candidate "{cand_name}" to '
                'election "{name}"')
            kwargs['cand_name'] = msg['msg']['candidate']['name']
        elif 'candidate.edit' in msg['topic']:
            tmpl = self._(
                '{agent} edited candidate "{cand_name}" of '
                'election "{name}"')
            kwargs['cand_name'] = msg['msg']['candidate']['name']
        elif 'candidate.delete' in msg['topic']:
            tmpl = self._(
                '{agent} deleted candidate "{cand_name}" of '
                'election "{name}"')
            kwargs['cand_name'] = msg['msg']['candidate']['name']
        else:
            tmpl = ''

        return tmpl.format(**kwargs)

    def secondary_icon(self, msg, **config):
        if 'agent' in msg['msg']:
            agent = msg['msg']['agent']  # Old style
        else:
            agent = msg['msg']['fas_user']  # New style
        return avatar_url(agent)

    def usernames(self, msg, **config):
        try:
            if 'agent' in msg['msg']:
                agent = msg['msg']['agent']  # Old style
            else:
                agent = msg['msg']['fas_user']  # New style
            return set([agent])
        except KeyError:
            return set()

    def objects(self, msg, **config):
        kind = msg['topic'].split('.')[-2]
        action = msg['topic'].split('.')[-1]

        if 'election' in msg['msg']:
            name = msg['msg']['election']['alias']  # Old style
        else:
            name = msg['msg']['alias']  # New style

        tokens = [name, kind, action]
        return set(['/'.join(map(str, tokens))])



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#

import datetime
import dateutil.relativedelta

from fedmsg_meta_fedora_infrastructure import BaseProcessor

from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url


def _get_common_attrs(msg):
    try:
        user = msg['msg']['agent']
    except KeyError:
        user = None

    try:
        calendar = msg['msg']['calendar']['calendar_name']
    except KeyError:
        calendar = None

    try:
        meeting = msg['msg']['meeting']['meeting_name']
    except KeyError:
        meeting = None

    return user, calendar, meeting


def _casual_timedelta_string(meeting):
    """ Return a casual timedelta string.

    If a meeting starts in 2 hours, 15 minutes, and 32 seconds from now, then
    return just "in 2 hours".

    If a meeting starts in 7 minutes and 40 seconds from now, return just "in 7
    minutes".

    If a meeting starts 56 seconds from now, just return "right now".

    """

    now = datetime.datetime.utcnow()
    mdate = meeting['meeting_date']
    mtime = meeting['meeting_time_start']
    dt_string = "%s %s" % (mdate, mtime)
    meeting_dt = datetime.datetime.strptime(dt_string, "%Y-%m-%d %H:%M:%S")
    relative_td = dateutil.relativedelta.relativedelta(meeting_dt, now)

    denominations = ['years', 'months', 'days', 'hours', 'minutes']
    for denomination in denominations:
        value = getattr(relative_td, denomination)
        if value:
            # If the value is only one, then strip off the plural suffix.
            if value == 1:
                denomination = denomination[:-1]
            return "in %i %s" % (value, denomination)

    return "right now"


class FedocalProcessor(BaseProcessor):
    __name__ = "fedocal"
    __description__ = "The Fedora Calendaring System"
    __link__ = "https://apps.fedoraproject.org/calendar"
    __icon__ = "https://apps.fedoraproject.org/calendar/static/calendar.png"
    __docs__ = "https://github.com/fedora-infra/fedocal"
    __obj__ = "Calendar Events"

    def subtitle(self, msg, **config):
        user, calendar, meeting = _get_common_attrs(msg)
        timestring = None
        if 'fedocal.meeting.reminder' in msg['topic']:
            timestring = _casual_timedelta_string(msg['msg']['meeting'])
            tmpl = self._(
                'Friendly reminder!  The "{meeting}" meeting from '
                'the "{calendar}" calendar starts {timestring}')
        elif 'fedocal.meeting.update' in msg['topic']:
            tmpl = self._(
                '{user} updated the "{meeting}" meeting from '
                'the "{calendar}" calendar')
        elif 'fedocal.meeting.delete' in msg['topic']:
            tmpl = self._(
                '{user} deleted the "{meeting}" meeting from '
                'the "{calendar}" calendar')
        elif 'fedocal.meeting.new' in msg['topic']:
            tmpl = self._(
                '{user} created a "{meeting}" meeting in '
                'the "{calendar}" calendar')
        elif 'fedocal.calendar.new' in msg['topic']:
            tmpl = self._('{user} created a whole new "{calendar}" calendar')
        elif 'fedocal.calendar.update' in msg['topic']:
            tmpl = self._('{user} updated the "{calendar}" calendar')
        elif 'fedocal.calendar.delete' in msg['topic']:
            tmpl = self._('{user} deleted the "{calendar}" calendar')
        elif 'fedocal.calendar.clear' in msg['topic']:
            tmpl = self._(
                '{user} cleared the "{calendar}" calendar of all its meetings')
        elif 'fedocal.calendar.upload' in msg['topic']:
            tmpl = self._(
                '{user} uploaded an iCalendar file into the calendar '
                '"{calendar}"')
        else:
            tmpl = ""

        return tmpl.format(
            user=user,
            calendar=calendar,
            meeting=meeting,
            timestring=timestring,
        )

    def secondary_icon(self, msg, **config):
        try:
            user = msg['msg']['agent']
            return avatar_url(user)
        except KeyError:
            return None

    def link(self, msg, **config):
        base = "https://apps.fedoraproject.org/calendar/"
        try:
            meeting_id = msg['msg']['meeting']['meeting_id']
            return base + "meeting/%i/" % meeting_id
        except KeyError:
            return base + msg['msg']['calendar']['calendar_name'] + "/"

    def usernames(self, msg, **config):
        try:
            return set([msg['msg']['agent']])
        except KeyError:
            return set()

    def objects(self, msg, **config):
        user, calendar, meeting = _get_common_attrs(msg)
        action = msg['topic'].split('.')[-1]

        if not meeting:
            items = [calendar, action]
        else:
            items = [calendar, 'meetings', meeting, action]

        return set(['/'.join(items)])



# This file is part of fedmsg.
# Copyright (C) 2015 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
from fedmsg_meta_fedora_infrastructure import BaseProcessor


class PungiKojiProcessor(BaseProcessor):
    __name__ = "pungi"
    __description__ = "Fedora Release Engineering"
    __link__ = "https://pagure.io/releng"
    __docs__ = "https://pagure.io/docs/releng"
    __obj__ = "Composes"

    def subtitle(self, msg, **config):
        compose = msg['msg']['compose_id']
        if msg['topic'].endswith('pungi.compose.status.change'):
            statuses = {
                'STARTED': self._('started'),
                'FINISHED': self._('just finished'),
                'DOOMED': self._('failed in a horrible fire'),
            }
            status = statuses.get(msg['msg']['status'], msg['msg']['status'])
            tmpl = self._("pungi-koji compose of {compose} {status}")
            return tmpl.format(compose=compose, status=status)
        elif msg['topic'].endswith('pungi.compose.phase.start'):
            phase = msg['msg']['phase_name']
            tmpl = self._("pungi-koji started the {phase} phase "
                          "of the {compose} compose")
            return tmpl.format(compose=compose, phase=phase)
        elif msg['topic'].endswith('pungi.compose.phase.stop'):
            phase = msg['msg']['phase_name']
            tmpl = self._("pungi-koji finished the {phase} phase "
                          "of the {compose} compose")
            return tmpl.format(compose=compose, phase=phase)
        elif msg['topic'].endswith('pungi.compose.createiso.imagedone'):
            image = msg['msg']['file'].split('compose/')[-1]
            tmpl = self._("pungi-koji finished createiso for {image}")
            return tmpl.format(image=image)
        elif msg['topic'].endswith('pungi.compose.createiso.imagefail'):
            image = msg['msg']['file'].split('compose/')[-1]
            tmpl = self._("pungi-koji createiso for {image} failed!")
            return tmpl.format(image=image)
        elif msg['topic'].endswith('pungi.compose.createiso.targets'):
            N = len(msg['msg']['deliverables'])
            tmpl = self._("pungi-koji assigned {N} createiso targets")
            return tmpl.format(N=N)

    def link(self, msg, **config):
        if 'location' in msg['msg']:
            return msg['msg']['location'].strip('/').strip('/compose')

    def objects(self, msg, **config):
        if 'deliverables' in msg['msg']:
            return set([d.strip('/') for d in msg['msg']['deliverables']])
        elif 'file' in msg['msg']:
            return set([msg['msg']['file'].strip('/')])
        else:
            compose = msg['msg']['compose_id']
            return set(["rawhide/" + "/".join(compose.split('.'))])



# This file is part of fedmsg.
# Copyright (C) 2013 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for coprs messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


_long_copr_end = """Package:  mutt-kz-1.5.23.1-1.20150203.git.c8504a8a.fc21
COPR:     fatka/mutt-kz
Built by: fatka
Status:   success
ID:       00000100

Logs:
  Build:     https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/00000100-mutt-kz/build.log.gz
  Root:      https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/00000100-mutt-kz/root.log.gz
  Copr:      https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/build-00000100.log
  Mockchain: https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/00000100-mutt-kz/mockchain.log.gz
Results:     https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/00000100-mutt-kz/
Repodata:    https://copr-be.cloud.fedoraproject.org/results/fatka/mutt-kz/fedora-20-x86_64/repodata/
"""


_long_copr_end_fail = """Package:  glib2-2.42.2-1.01.fc21
COPR:     brianjmurrell/glib2
Built by: brianjmurrell
Status:   failed
ID:       00080794

Logs:
  Build:     https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/00080794-glib2/build.log.gz
  Root:      https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/00080794-glib2/root.log.gz
  Copr:      https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/build-00080794.log
  Mockchain: https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/00080794-glib2/mockchain.log.gz
Results:     https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/00080794-glib2/
Repodata:    https://copr-be.cloud.fedoraproject.org/results/brianjmurrell/glib2/fedora-21-x86_64/repodata/
"""


class TestCoprsBuildStart(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a new build starts.
    """
    expected_title = "copr.build.start"
    expected_subti = ("fatka started a new build of the mutt-kz copr")
    expected_icon = 'https://apps.fedoraproject.org/img/icons/copr.png'
    expected_secondary_icon = (
        'https://seccdn.libravatar.org/avatar/'
        'b9d974c03597da48d9c3b11d4423bf30c6e0c01c23bcd3a192167a95f7c506bc?'
        's=64&d=retro')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/build.start',
    ])
    expected_link = (
        "https://copr.fedoraproject.org/coprs/fatka/mutt-kz/build/100/")
    msg = {
        u'username': u'copr',
        u'i': 1,
        u'timestamp': 1383956077.2320001,
        u'msg_id': u'2013-675e7b1e-9b7f-4d11-be2f-2b3845817d60',
        u'topic': u'org.fedoraproject.prod.copr.build.start',
        u'msg': {
            u'what': u'build start: user:fatka copr:mutt-kz '
            'build:100 ip:172.16.3.3  pid:12010',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsBuildEnd(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a build has completed.  This is an example of a build that **completed
    successfully**.
    """
    expected_title = "copr.build.end"
    expected_subti = (
        "fatka's mutt-kz copr build of "
        "mutt-kz-1.5.23.1-1.20150203.git.c8504a8a.fc21 "
        "for fedora-20-x86_64 finished with 'success'")
    expected_long_form = _long_copr_end
    expected_secondary_icon = (
        'https://seccdn.libravatar.org/avatar/'
        'b9d974c03597da48d9c3b11d4423bf30c6e0c01c23bcd3a192167a95f7c506bc?'
        's=64&d=retro')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/build.end',
    ])
    expected_link = (
        "https://copr.fedoraproject.org/coprs/fatka/mutt-kz/build/100/")
    msg = {
        u'username': u'copr',
        u'i': 4,
        u'timestamp': 1383956707.6340001,
        u'msg_id': u'2013-b05a323d-37ee-4396-9635-7b5dfaf5441b',
        u'topic': u'org.fedoraproject.prod.copr.build.end',
        u'msg': {
            u'status': 1,
            u'chroot': u'fedora-20-x86_64',
            u'what': u'build end: user:fatka copr:mutt-kz build:100 '
            'ip:172.16.3.3  pid:12010 status:1',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'version': '1.5.23.1-1.20150203.git.c8504a8a.fc21',
            u'pkg': 'mutt-kz-1.5.23.1-1.20150203.git.c8504a8a.fc21',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsBuildFailure(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a build has completed.  This is an example of a build that **failed**.
    """
    expected_title = "copr.build.end"
    expected_subti = (
        "brianjmurrell's glib2 copr build of "
        "glib2-2.42.2-1.01.fc21 "
        "for fedora-21-x86_64 finished with 'failed'")
    expected_long_form = _long_copr_end_fail
    expected_secondary_icon = (
        'https://seccdn.libravatar.org/avatar/'
        '7de251444538e68ddf2e83d67749c5f09583ae7b3fd638df3490c7e672c148d8?'
        's=64&d=retro')
    expected_packages = set([])
    expected_usernames = set(['brianjmurrell'])
    expected_objects = set([
        'coprs/glib2/build.end',
    ])
    expected_link = ("https://copr.fedoraproject.org/coprs/"
                     "brianjmurrell/glib2/build/80794/")

    msg = {
        "timestamp": 1425653769.0,
        "msg_id": "2015-f3152f3c-5075-422e-af94-96c692454c81",
        "topic": "org.fedoraproject.prod.copr.build.end",
        "msg": {
            "status": 0,
            "what": "build end: user:brianjmurrell copr:glib2 build:80794    "
            "pkg: glib2-2.42.2-1.01.fc21    version: 2.42.2-1.01.fc21 "
            "ip:172.16.3.5    pid:9363 status:0",
            "chroot": "fedora-21-x86_64",
            "ip": "172.16.3.5",
            "user": "brianjmurrell",
            "who": "worker-4",
            "pid": 9363,
            "copr": "glib2",
            "version": "2.42.2-1.01.fc21",
            "build": 80794,
            "owner": "brianjmurrell",
            "pkg": "glib2",
        }
    }


class TestCoprsChrootStart(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a copr start a new chroot.
    """
    expected_title = "copr.chroot.start"
    expected_subti = (
        "fatka's mutt-kz copr started a new fedora-20-x86_64 chroot")
    expected_secondary_icon = (
        'https://seccdn.libravatar.org/avatar/'
        'b9d974c03597da48d9c3b11d4423bf30c6e0c01c23bcd3a192167a95f7c506bc?'
        's=64&d=retro')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/chroot.start/fedora-20-x86_64',
    ])
    expected_link = (
        "https://copr-be.cloud.fedoraproject.org/results/"
        "fatka/mutt-kz/fedora-20-x86_64/")
    msg = {
        u'username': u'copr',
        u'i': 3,
        u'timestamp': 1383956378.4679999,
        u'msg_id': u'2013-833cca09-2dba-42ad-9863-4f6c3c29a30d',
        u'topic': u'org.fedoraproject.prod.copr.chroot.start',
        u'msg': {
            u'what': u'chroot start: chroot:fedora-20-x86_64 user:fatka '
            'copr:mutt-kz build:100 ip:172.16.3.3  pid:12010',
            u'chroot': u'fedora-20-x86_64',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsWorkerCreate(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a new worker is spun up.
    """
    expected_title = "copr.worker.create"
    expected_subti = "a new worker was created"
    expected_link = "https://copr.fedoraproject.org"
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set([
        'coprs/worker.create',
    ])
    msg = {
        u'username': u'copr',
        u'i': 1,
        u'timestamp': 1383956077.2320001,
        u'msg_id': u'2013-675e7b1e-9b7f-4d11-be2f-2b3845817d60',
        u'topic': u'org.fedoraproject.prod.copr.worker.create',
        u'msg': {
            u'what': u'creating worker: 172.16.3.3',
            u'ip': u'172.16.3.3',
        },
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for nuancier messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestNuancierElectionUpdated(Base):
    """ These messages are published when **an admin updates the details** of
    an existing election on the "Nuancier" wallpaper voting app.
    """

    expected_title = "nuancier.election.update"
    expected_subti = 'ralph changed the following details on the ' + \
        '"Fedora 21" election: election year, election name'
    expected_link = "https://apps.fedoraproject.org/nuancier/election/1"
    expected_icon = "https://apps.fedoraproject.org/img/icons/nuancier.png"
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['ralph'])
    expected_objects = set(['2014/Fedora 21/election/update'])
    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1392907947,
        "msg_id": "2014-a97d68bd-bc9e-49e0-b028-f10297f36767",
        "topic": "org.fedoraproject.dev.nuancier.election.update",
        "msg": {
            "updated": [
                "election year",
                "election name"
            ],
            "election": {
                "name": "Fedora 21",
                "submission_date_start": 1392958800.0,
                "date_end": 1393045200.0,
                "date_start": 1392958800.0,
                "year": "2014",
                "id": 1
            },
            "agent": "ralph"
        }
    }


class TestNuancierElectionCreate(Base):
    """ These messages are published when **an admin creates** a new election
    on the "Nuancier" wallpaper voting app.
    """

    expected_title = "nuancier.election.new"
    expected_subti = 'ralph created a new election "Fedora 22"'
    expected_link = "https://apps.fedoraproject.org/nuancier/election/4"
    expected_icon = "https://apps.fedoraproject.org/img/icons/nuancier.png"
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['ralph'])
    expected_objects = set(['2015/Fedora 22/election/new'])
    msg = {
        "username": "threebean",
        "i": 1,
        "timestamp": 1392908460,
        "msg_id": "2014-88577310-f466-4c88-8deb-dc98c8abc09e",
        "topic": "org.fedoraproject.dev.nuancier.election.new",
        "msg": {
            "election": {
                "name": "Fedora 22",
                "submission_date_start": 1392786000.0,
                "date_end": 1393045200.0,
                "date_start": 1392786000.0,
                "year": "2015",
                "id": 4
            },
            "agent": "ralph"
        }
    }


class TestNuancierCandidateNew(Base):
    """ These messages are published when **a contributor submits a new
    candidate** for an existing election on the "Nuancier" wallpaper voting
    app.
    """

    expected_title = "nuancier.candidate.new"
    expected_subti = 'ralph uploaded a new candidate for the ' + \
        '"Fedora 22" wallpaper election'
    expected_link = "http://www.cyclelicio.us/wp-content/" + \
        "uploads/2013/07/skvidal.jpg"
    expected_icon = "https://apps.fedoraproject.org/img/icons/nuancier.png"
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['ralph'])
    expected_objects = set(['2015/Fedora 22/Handsome/candidate/new'])
    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1392908853,
        "msg_id": "2014-0838ce6a-9f99-41d9-84a4-e076665d3b2b",
        "topic": "org.fedoraproject.dev.nuancier.candidate.new",
        "msg": {
            "agent": "ralph",
            "candidate": {
                "submitter": "ralph",
                "author": "ralph",
                "name": "Handsome",
                "license": "CC-BY-SA",
                "original_url": "http://www.cyclelicio.us/wp-content/"
                "uploads/2013/07/skvidal.jpg"
            },
            "election": {
                "name": "Fedora 22",
                "submission_date_start": 1392786000.0,
                "date_end": 1393045200.0,
                "date_start": 1392958800.0,
                "year": 2015,
                "id": 4
            }
        }
    }


class TestNuancierCandidateApprove(Base):
    """ These messages are published when **an admin approves** a candidate
    submission to the "Nuancier" wallpaper voting app.
    """

    expected_title = "nuancier.candidate.approved"
    expected_subti = 'gnokii approved ralph\'s "Handsome" submission ' + \
        'to the "Fedora 22" wallpaper election'
    expected_link = "http://www.cyclelicio.us/wp-content/" + \
        "uploads/2013/07/skvidal.jpg"
    expected_icon = "https://apps.fedoraproject.org/img/icons/nuancier.png"
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "f0f0eef56d80913ec82275ed76dafe440ef8b4bba0228d97e7fb2ecb275d9591"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['ralph', 'gnokii'])
    expected_objects = set(['2015/Fedora 22/Handsome/candidate/approved'])
    msg = {
        "username": "threebean",
        "i": 1,
        "timestamp": 1392916813,
        "msg_id": "2014-32dce0de-5d80-4f9e-a445-d63b6f9e320f",
        "topic": "org.fedoraproject.dev.nuancier.candidate.approved",
        "msg": {
            "agent": "gnokii",
            "candidate": {
                "submitter": "ralph",
                "author": "ralph",
                "name": "Handsome",
                "license": "CC-BY-SA",
                "original_url": "http://www.cyclelicio.us/wp-content/"
                "uploads/2013/07/skvidal.jpg"
            },
            "election": {
                "name": "Fedora 22",
                "submission_date_start": 1392786000.0,
                "date_end": 1393045200.0,
                "date_start": 1392958800.0,
                "year": 2015,
                "id": 4
            }
        }
    }


class TestNuancierCandidateDeny(Base):
    """ These messages are published when **an admin denies** a candidate
    submission to the "Nuancier" wallpaper voting app.
    """

    expected_title = "nuancier.candidate.denied"
    expected_subti = 'gnokii denied ralph\'s "Handsome" submission ' + \
        'to the "Fedora 22" wallpaper election'
    expected_link = "http://www.cyclelicio.us/wp-content/" + \
        "uploads/2013/07/skvidal.jpg"
    expected_icon = "https://apps.fedoraproject.org/img/icons/nuancier.png"
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "f0f0eef56d80913ec82275ed76dafe440ef8b4bba0228d97e7fb2ecb275d9591"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['ralph', 'gnokii'])
    expected_objects = set(['2015/Fedora 22/Handsome/candidate/denied'])
    msg = {
        "username": "threebean",
        "i": 1,
        "timestamp": 1392916813,
        "msg_id": "2014-32dce0de-5d80-4f9e-a445-d63b6f9e320f",
        "topic": "org.fedoraproject.dev.nuancier.candidate.denied",
        "msg": {
            "agent": "gnokii",
            "candidate": {
                "submitter": "ralph",
                "author": "ralph",
                "name": "Handsome",
                "license": "CC-BY-SA",
                "original_url": "http://www.cyclelicio.us/wp-content/"
                "uploads/2013/07/skvidal.jpg"
            },
            "election": {
                "name": "Fedora 22",
                "submission_date_start": 1392786000.0,
                "date_end": 1393045200.0,
                "date_start": 1392958800.0,
                "year": 2015,
                "id": 4
            }
        }
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
import six

from fedmsg_meta_fedora_infrastructure import BaseProcessor
from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url


def string_or_dict(msg, key):
    if isinstance(msg[key], six.text_type):
        return msg[key]
    else:
        if 'username' in msg[key]:
            return msg[key]['username']
        else:
            return msg[key]['name']


class FASProcessor(BaseProcessor):
    __name__ = "FAS"
    __description__ = "the Fedora Account System"
    __link__ = "https://admin.fedoraproject.org/accounts"
    __docs__ = "https://fedoraproject.org/wiki/Account_System"
    __obj__ = "Account Changes"
    __icon__ = ("https://admin.fedoraproject.org/accounts/static/"
                "theme/fas/images/account.png")

    def subtitle(self, msg, **config):
        if 'fas.user.create' in msg['topic']:
            agent = string_or_dict(msg['msg'], 'agent')
            user = string_or_dict(msg['msg'], 'user')
            tmpl = self._(
                "New FAS account:  '{user}'  (created by '{agent}')"
            )
            return tmpl.format(agent=agent, user=user)
        elif 'fas.user.update' in msg['topic']:
            agent = string_or_dict(msg['msg'], 'agent')
            user = string_or_dict(msg['msg'], 'user')
            fields = ", ".join(msg['msg']['fields'])
            tmpl = self._(
                "{agent} edited the following fields of " +
                "{user}'s FAS profile:  {fields}"
            )
            return tmpl.format(agent=agent, user=user, fields=fields)
        elif 'fas.group.member.' in msg['topic']:
            action = msg['topic'].split('.')[-1]
            agent = string_or_dict(msg['msg'], 'agent')
            user = string_or_dict(msg['msg'], 'user')
            group = string_or_dict(msg['msg'], 'group')
            tmpls = {
                'apply': self._(
                    "{agent} applied for {user}'s membership " +
                    "in the {group} group"
                ),
                'sponsor': self._(
                    "{agent} sponsored {user}'s membership " +
                    "in the {group} group"
                ),
                'remove': self._(
                    "{agent} removed {user} from " +
                    "the {group} group"
                ),
            }
            tmpl = tmpls.get(action, self._(
                '<unhandled action in fedmsg.meta.fas>'
            ))
            return tmpl.format(agent=agent, user=user, group=group)
        elif 'fas.group.create' in msg['topic']:
            agent = string_or_dict(msg['msg'], 'agent')
            group = string_or_dict(msg['msg'], 'group')
            tmpl = self._("{agent} created new FAS group {group}")
            return tmpl.format(agent=agent, group=group)
        elif 'fas.group.update' in msg['topic']:
            agent = string_or_dict(msg['msg'], 'agent')
            group = string_or_dict(msg['msg'], 'group')
            fields = ", ".join(msg['msg']['fields'])
            tmpl = self._(
                "{agent} edited the following fields of the {group} " +
                "FAS group:  {fields}"
            )
            return tmpl.format(agent=agent, group=group, fields=fields)
        elif 'fas.role.update' in msg['topic']:
            tmpl = self._(
                "{agent} changed {user}'s role in the {group} group"
            )
            agent = string_or_dict(msg['msg'], 'agent')
            user = string_or_dict(msg['msg'], 'user')
            group = string_or_dict(msg['msg'], 'group')
            if 'status' in msg['msg']:
                status = string_or_dict(msg['msg'], 'status')
                tmpl += self._(' to {status}')
            else:
                status = None
            return tmpl.format(agent=agent,
                               group=group,
                               user=user,
                               status=status)
        else:
            raise NotImplementedError("%r" % msg)

    def secondary_icon(self, msg, **config):
        # Every fas fedmsg message has an "agent" field.. "whodunnit"
        return avatar_url(username=string_or_dict(msg['msg'], 'agent'))

    def usernames(self, msg, **config):
        users = []

        try:
            users.append(string_or_dict(msg['msg'], 'agent'))
        except KeyError:
            pass

        try:
            users.append(string_or_dict(msg['msg'], 'user'))
        except KeyError:
            pass

        return set(users)

    def objects(self, msg, **config):
        objs = set()

        if 'user' in msg['msg']:
            objs.add('users/' + string_or_dict(msg['msg'], 'user'))

        if 'group' in msg['msg']:
            objs.add('groups/' + string_or_dict(msg['msg'], 'group'))

        return objs
